#
# spec file for package mongodb
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _home_dir       %{_var}/lib/%{name}
%define _mongodb_user     %{name}
%define _mongodb_group    %{name}

Name:           mongodb
Version:        2.4.3
Release:        2.1
Url:            http://www.mongodb.org
Summary:        High-performance, schema-free document-oriented database
License:        AGPL-3.0 and Apache-2.0
Group:          Productivity/Databases/Servers
Source0:        mongodb-src-r%{version}.tar.gz
Source1:        mongodb.init
Source2:        mongodb.logrotate
Source3:        mongodb.conf
Patch0:         mongodb-no-werror.patch
Patch1:         void_return.patch
# FIX-FOR-UPSTREAM https://jira.mongodb.org/browse/SERVER-5575 - fix the "--full" flag i586 build error.
Patch2:         %{name}-%{version}-mongodb_scons-full-flag.patch
# FIX-FOR-UPSTREAM openssl 0.9.8 has no FIPS.
Patch3:		mongodb-ssl-FIPS_mode_set.patch
BuildRequires:  boost-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libpcap-devel
BuildRequires:  libstdc++-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  python-devel >= 2.6
BuildRequires:  readline-devel
BuildRequires:  scons >= 1.1
#BuildRequires:  v8-devel
Requires:       glibc-locale
Requires:       logrotate
Requires(pre):  %{fillup_prereq}
Requires(pre):  %{insserv_prereq}
Requires(post): %{insserv_prereq}
Requires(pre):  pwdutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    ppc ppc64 s390x

%description
Mongo (from "humongous") is a high-performance, open source, schema-free
document-oriented database. MongoDB is written in C++ and offers the following
features:
    * Collection oriented storage: easy storage of object/JSON-style data
    * Dynamic queries
    * Full index support, including on inner objects and embedded arrays
    * Query profiling
    * Replication and fail-over support
    * Efficient storage of binary data including large objects (e.g. photos
    and videos)
    * Auto-sharding for cloud-level scalability (currently in early alpha)
    * Commercial Support Available

A key goal of MongoDB is to bridge the gap between key/value stores (which are
fast and highly scalable) and traditional RDBMS systems (which are deep in
functionality).

%package devel
Summary:        High-performance, schema-free document-oriented database
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Mongo (from "humongous") is a high-performance, open source, schema-free
document-oriented database.

This package contains headers and static libraries necessary for development.

%prep
%setup -q -n mongodb-src-r%{version}
%patch0 -p1
%if 0%{?suse_version} < 1120
# strange, maybe, boost::filesystem::remove is void here, and bool later?
%patch1 -p1
%endif
%ifarch i586
%patch2 -p1
%endif
%if 0%{?suse_version} <= 1210
%patch3 -p1
%endif
# change dbpath
sed -i 's|/data/db/|%{_home_dir}/|' src/mongo/db/pdfile.cpp
chmod a-x README

%build
export CPPFLAGS=$(echo "%{optflags}" | sed "s|-Wall|-Wno-error|")
#NOTE(saschpe): Use "system" allocator, tcmalloc isn't packaged yet:
scons %{?_smp_mflags} --prefix=%{_prefix} --nostrip --full --ssl \
%if 0%{?suse_version} > 1230
    --use-system-boost \
%endif
    --use-system-pcre

%install
scons install --prefix=%{buildroot}%{_prefix}
install -d -m 0755                              \
    %{buildroot}%{_sysconfdir}/init.d           \
    %{buildroot}%{_sysconfdir}/logrotate.d      \
    %{buildroot}%{_bindir}                      \
    %{buildroot}%{_libdir}                      \
    %{buildroot}%{_sbindir}                     \
    %{buildroot}%{_mandir}/man1                 \
    %{buildroot}%{_localstatedir}/lib/mongodb   \
    %{buildroot}%{_localstatedir}/log/mongodb
mv %{buildroot}%{_bindir}/mongod %{buildroot}%{_sbindir}
install -m 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/%{name}
ln -sf /etc/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
install -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}.conf
install -m 0644 debian/*.1 %{buildroot}%{_mandir}/man1/
%ifarch x86_64
mv %{buildroot}%{_prefix}/lib/libmongoclient.a %{buildroot}%{_libdir}/
%endif

find %{buildroot}%{_includedir} -type f -name "*.h" -exec chmod -x {} \;
%fdupes %{buildroot}

%pre
/usr/sbin/groupadd -r %{_mongodb_group} >/dev/null 2>/dev/null || :
/usr/sbin/useradd -r -g %{_mongodb_group} -c "MongoDB database admin" \
                  -s /bin/false -d %{_home_dir} %{_mongodb_user} 2> /dev/null || :
/usr/sbin/usermod -g %{_mongodb_group} -s /bin/false %{_mongodb_user} || :

%post
/sbin/ldconfig
%{fillup_and_insserv -f %{name}}

%preun
%{stop_on_removal %{name}}

%postun
/sbin/ldconfig
%{restart_on_update %{name}}
%{insserv_cleanup}

%files
%defattr(-,root,root,-)
%doc README GNU-AGPL-3.0.txt APACHE-2.0.txt
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_mandir}/man1/*
%{_bindir}/bsondump
%{_bindir}/mongo*
%{_sbindir}/mongod
%{_sbindir}/rc%{name}
%{_sysconfdir}/init.d/%{name}
%attr(0750,mongodb,mongodb) %{_var}/log/mongodb
%attr(0750,mongodb,mongodb) %{_var}/lib/mongodb

%files devel
%defattr(-,root,root,-)
%{_includedir}/mongo
%{_libdir}/libmongoclient.a

%changelog
* Fri Feb 21 2014 speilicke@suse.com
- Fixed mongodb-2.4.3-mongodb_scons-full-flag.patch: i586 build broken
  due to path issues
* Thu Feb 13 2014 jsuchome@suse.cz
- tell logrotate about log file ownership (bnc#863719)
* Tue Oct 29 2013 speilicke@suse.com
- Simplify chmod'ing include headers
- Drop old include dirs from devel package
* Mon Oct 28 2013 speilicke@suse.com
- Disable -Werror where appropriate
- Build with system libraries: boost, pcre
- Drop v8 build conditional, it never had any effect anyway since this was the default
- Use in-tree v8 for now until someone wants to fix the fallout from
  different distro versions
* Wed Oct 16 2013 speilicke@suse.com
- Don't build with "-Wall", there far to many errors which just don't
  make sense to fix
* Mon Sep 16 2013 speilicke@suse.com
- Require scons >= 1.1.0, build will fail otherwise
* Wed Aug 21 2013 dvaleev@suse.com
- Disable building for BigEndian platforms
* Wed Aug 21 2013 dvaleev@suse.com
- don't enable service by default. It is up to user whether he
  wants to start the service automatically
* Fri May 24 2013 i@marguerite.su
- New upstream release 2.4.3
  * see http://docs.mongodb.org/manual/release-notes/2.4/
* Tue Apr 30 2013 dmueller@suse.com
- remove -o flag from useradd
  * useradd: -o flag is only allowed with the -u flag
* Fri Dec 21 2012 fcastelli@suse.com
- Ensure mongodb is started properly on NUMA machines
  (http://docs.mongodb.org/manual/administration/production-notes/#production-numa)
* Fri Nov 23 2012 mrueckert@suse.de
- use _home_dir define in the sed line
* Sat Sep 22 2012 i@marguerite.su
- New upstream release 2.2.0
  * see http://docs.mongodb.org/manual/release-notes/2.2/
- Remove deprecated_boost_functions.patch (Patch0)
  * upstream changed it as a warning.
- Regenerate void_return.patch (Patch1)
  * seems it aims to deal with the strange boost::filesystem::remove
- Drop mongodb-third_party.sm.py.patch (Patch2)
  * upstream rewrote its code, no its cpp instead of py.
- Drop mongodb-2.0.0_no_stupid_chmod.patch (Patch3)
  * no such code in SConstruct.
- Drop mongodb-src-r2.0.4_link_ssl.patch (Patch4)
  * upstream fixed.
- Drop mongodb_cxxflags.patch (Patch5)
  * not used at all.
- Fix i586 build.
  * mongodb-2.2.0-mongodb_scons-full-flag.patch
  * https://jira.mongodb.org/browse/SERVER-5575
* Fri Jul 20 2012 jengelh@inai.de
- Package /var/{lib,log}/mongodb, as they are needed for proper
  operation of the daemon which would otherwise refuse to start.
- Remove redundant sections from specfile
* Wed Apr 11 2012 simone.tolotti@gmail.com
- New upstream release 2.0.4
- Fixes (https://jira.mongodb.org/browse/SERVER/fixforversion/11107):
  * SERVER-5135 Journal compression ratio reporting is incorrect
  * SERVER-5177 fetching of docs in initial sync can assert
  * SERVER-5069 ~ScopedDBConnection is vague and somewhat misleading
* Thu Nov 17 2011 mrueckert@suse.de
- add back mongodb_cxxflags.patch
* Thu Nov 17 2011 mrueckert@suse.de
- added mongodb-src-r2.0.1_link_ssl.patch:
  Fix linking on factory. We need libcrypto in the library list
  there.
* Thu Nov 17 2011 mrueckert@suse.de
- fix build on sles. it didnt like some of our scons parameters
* Thu Nov 17 2011 mrueckert@suse.de
- update to 2.0.1
  - SERVER-3961 Segmentation Fault when creating new indexes
  - SERVER-4020 bad serverID set in setShardVersion
  - SERVER-3889 Possible for setShardVersion to never be set on
    mongod after multiple StaleConfigExceptions due to reset
    metadata
  - SERVER-3572 authenticate shouldn't use a write lock
  - SERVER-4091 rs.reconfig(...) on 1.8.4_rc0 causes server to exit
  - SERVER-3058 make sure distributed locks are thread-safe to
    acquire
  - SERVER-3683 Possible for setShardVersion to never be set on
    mongod after multiple StaleConfigExceptions due to
    stale/missing mongod metadata
  - SERVER-3594 new crash in 1.9.1: couldn't make room for new
    record (len: 135548) in capped ns <database>.system.profile
  - SERVER-3650 ReplicaSet rollback should use slaveOk
  - SERVER-3705 mongos not closing connections, filling up disk
    with logs
  - SERVER-3729 --ssl for tools
  - SERVER-3750 Need to limit size of backfilled elements when
    creating an array
  - SERVER-3619 mongostat can't authenticate to mongos using -u -p
    or the long name equivalents
  - SERVER-3605 After node is restarted it may not be set to ok
    state in mongos
  - SERVER-3666 mongod --auth must disable __system access
  - SERVER-3539 mongos returns duplicate "ns" element when you run
    db.xyz.stats()
  - SERVER-1097 mongoimport / export should adhere to CSV spec
  - SERVER-3462 slaveOk queries don't distribute to all secondaries
    when using a mongos
  - SERVER-2710 Running replSetReconfig while writing to a
    collection causes secondaries and arbiters to segfault.
  - SERVER-2976 add a pure JS mode to map reduce to get improved
    performance for light jobs
  - SERVER-3086 mongoexport only exports one shard's worth of data
  - SERVER-2872 mongos client/lasterror instability
  - SERVER-2792 replace readline with linenoise
  - SERVER-1503 rs priorities other than 0 and 1 not supported yet
  - SERVER-4196 Count command on mongos can get into infinite loop
  - SERVER-3683 Possible for setShardVersion to never be set on
    mongod after multiple StaleConfigExceptions due to
    stale/missing mongod metadata
  - SERVER-3529 Sharded map reduce using merge stalls recreating
    indexes on the output collection.
  - SERVER-3996 Backport fix for SERVER-3002 to v1.8 branch
- added optional switch to use libv8
- added mongodb-2.0.0_no_stupid_chmod.patch:
  dont do useless chmods
- minor spec file rework
* Mon Nov  7 2011 jmassaguerpla@suse.de
- added glibc-locale as a dependency
* Sun Nov  6 2011 jmassaguerpla@suse.de
- patched third-party/sm.py because of this bug
  http://scons.tigris.org/issues/show_bug.cgi?id=2800
* Thu Nov  3 2011 fcastelli@suse.com
- require libjs 1.7.0
* Fri Sep 30 2011 jw@suse.com
- made available also for SLE-11-SP1
* Wed Sep  7 2011 mrueckert@suse.de
- update to 1.8.3
  - [SERVER-3205] Dropping sharded database leads to errors with
    dbnames which are prefixes of dropped name
  - [SERVER-2707] make default stack size lower on linux
  - [SERVER-3507] Changing hostname in Replica Set configuration,
    does not affect rs.status(), until a server restart.
* Wed Sep  7 2011 mrueckert@suse.de
- added mongodb_werror.patch: drop -Werror from CFLAGS for building
  on older boost versions
* Wed Sep  7 2011 mrueckert@suse.de
- added b1ec2058673f8ca582a490c2dd4a8405698221ae.patch:
  patch taken from upstream git. adds detection code for linux3
* Wed Sep  7 2011 mrueckert@suse.de
- dont use PCH: it breaks build on SLE 11
* Wed Aug 17 2011 koprok@nand.bg
- Do not build libmongoclient.so shared library
* Mon Aug 15 2011 koprok@nand.bg
- Added -devel package with headers and static libraries
* Thu Aug 11 2011 mrueckert@suse.de
- update to 1.8.2
  - [SERVER-3188] CLONE - mongos crash with "Received signal 6"
  - [SERVER-1742] Assertion failure on mapreduce with geo query
  - [SERVER-3196] Segmentation Fault at startup on NUMA-Architecture
* Fri Apr 15 2011 mrueckert@suse.de
- update to 1.8.1
  - [SERVER-2324] compilation error with boost filesystem v3
  - [SERVER-2662] seg fault equivalent when query plan cannot
    recover from yield, does not assert, and is yielded again
  - [SERVER-2698] mongos seems to swallow 'No matching object
    found' errors when running findAndModify on a sharded
    collection.
  - [SERVER-2714] RS hidden setting should treat 1 as true
  - [SERVER-2719] mongod running as a service on Windows does not
    restart correctly after a reboot
  - [SERVER-2737] Large rollback fails (DR102 too much data written
    uncommitted) (after "rollback 6")
  - [SERVER-2762] backtrace of mongos crash
  - [SERVER-2787] Upgrading to 1.8.0 and enabling journaling
    causing cryptic "_a != -1" error
  - [SERVER-2791] missing write intent while initializing
    background index build job
  - [SERVER-2797] SEGV at BtreeCursor9prettyKey
  - [SERVER-2809] assertion in count / userquery op nscanned after
    failed yield recovery
  - [SERVER-2810] yield explain seg fault when accessing
    unprotected scan and order pointer
  - [SERVER-2815] DR102 on index creation w/dropDups + --journal
  - [SERVER-2853] Missing commitIfNeeded in background index build
  - [SERVER-2854] Unsafe to assert inside of CommitJob::note
  - [SERVER-2868] replica set connection gets confused about msater
  - [SERVER-2872] mongos client/lasterror instability
  - [SERVER-2808] when we get a seg fault (or similar) signal we
    should print the faulting address
- for the changes before see http://bit.ly/ga0jeH
- add /usr/sbin/usermod to the prereq
- respin mongodb_cxxflags.patch
* Tue Jan 18 2011 mhrusecky@suse.cz
- fixed build for openSUSE 11.2 (directory permissions)
* Tue Jan 18 2011 asn@cryptomilk.org
- Added missing build requirements for SLE
* Wed Jan 12 2011 asn@cryptomilk.org
- Added shared library to make binaries smaller.
- Added more comments to mongodb.conf
- Added support for CPPFLAGS.
- Don't strip the binaries for debuginfo packages.
* Mon Jan 10 2011 mhrusecky@suse.cz
- Using /etc/mongodb.conf instead of sysconfig
- Fixed init to run db as non-root
- Creating log and database directories in init script
- Added man pages
* Mon Jan  3 2011 asn@cynapses.org
- Added additional options
* Wed Dec 22 2010 asn@cynapses.org
- Fixed typo in mongodb init script.
* Wed Dec 22 2010 asn@cynapses.org
- Added a mongodb sysconfig file.
- Added localhost bind on startup.
- Added auth requirement on startup.
* Tue Dec 21 2010 asn@cynapses.org
- Silence mongodb daemon on startup.
* Tue Dec 21 2010 asn@cynapses.org
- Fixed logrotate requirement.
- Fixed the Group
* Tue Dec 21 2010 asn@cynapses.org
- Update to version 1.6.5
  * Attach a unique ID to moveChunk changelog entries
  * Check chunk boundaries of delete operations during chunk migration
  * Data loss after $set
  * replica sets connection safety
  * mongos doesn't pass mixed-case findAndModify
- Added a new working init script.
- Fixed directory permissions.
- Fixed spec file.
* Wed Oct 24 2001 jordimassaguerpla@gmail.com
- upgraded to mongodb 2.0.1
